#
# spec file for package qatzip
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           qatzip
Version:        1.1.2
Release:        1.3
Summary:        Intel QuickAssist Technology (QAT) QATzip Library
License:        BSD-3-Clause
Group:          Hardware/Other
URL:            https://github.com/intel/QATzip
Source:         https://github.com/intel/QATzip/archive/refs/tags/v%{version}.tar.gz
Patch0:         qatzip-fortify_source=3.patch
BuildRequires:  automake
BuildRequires:  gcc
BuildRequires:  liblz4-devel
BuildRequires:  libtool
BuildRequires:  qatlib-devel >= 22.07.0
BuildRequires:  zlib-devel >= 1.2.7
# This package can be built on all archs, but is useful only on enterprise-class intel.
ExclusiveArch:  x86_64

%description
QATzip is a user space library which builds on top of the Intel
QuickAssist Technology user space library, to provide extended
accelerated compression and decompression services by offloading the
actual compression and decompression request(s) to the Intel Chipset
Series. QATzip produces data using the standard gzip* format
(RFC1952) with extended headers. The data can be decompressed with a
compliant gzip* implementation. QATzip is designed to take full
advantage of the performance provided by Intel QuickAssist
Technology.

%package -n libqatzip3
Summary:        Libraries for the qatzip package
Group:          Hardware/Other

%description -n libqatzip3
This package contains libraries for applications to use
the QATzip APIs.

%package devel
Summary:        Development components for the libqatzip package
Group:          Hardware/Other
Requires:       libqatzip3%{?_isa} = %{version}-%{release}

%description devel
This package contains headers and libraries required to build
applications that use the QATzip APIs.

%prep
%autosetup -n QATzip-%{version}

%build
autoreconf -fiv
%configure --enable-symbol
%make_build

%install
%make_install
rm -vf %{buildroot}%{_mandir}/*.pdf
rm -vf %{buildroot}%{_libdir}/*.{la,a}

%post -n libqatzip3 -p /sbin/ldconfig
%postun -n libqatzip3 -p /sbin/ldconfig

%files
%license LICENSE*
%{_mandir}/man1/qzip.1%{?ext_man}
%{_bindir}/qzip

%files -n libqatzip3
%license LICENSE*
%{_libdir}/libqatzip.so.3*

%files devel
%doc docs/QATzip-man.pdf
%{_includedir}/qatzip.h
%{_libdir}/libqatzip.so
%{_libdir}/pkgconfig/qatzip.pc

%changelog
* Thu Oct 19 2023 ming li <mli@suse.com>
- update to 1.1.2:
  * Test: fix overflow on large files
  * Test: fix crash when perf test with svm
  * Fix Clang compile error
  * Fix MiniMatch bug
  * Fix compile error on QAT1.7
  * Update QAT1.7 / QAT2.0 config files
  * Update README
  * Update year in copyright information to 2023
  * Remove QAT device ID dependency
  * Update version, spec file, API PDF
  * Add missing QZ_PARAMS return code
* Mon Jan  2 2023 Dirk Müller <dmueller@suse.com>
- update to v1.1.1:
  * Add support for pkg-config in QATzip
  * Fix Coverity issues
  * Change lz4s with frame header to lz4s block
  * Move lz4(s) related functions to qatzip_lz4.c
  * Move functions outputHeader* outputFooter* to qatzip_utils.c
  * Fix bugs
* Sat Dec  3 2022 Dirk Müller <dmueller@suse.com>
- update to 1.1.0:
  * Add dependancy update tool file
  * Updated New "Crc" series API
  * Bug fix
  * Enable static link QATzip into Envoy
  * Support autoconf & automake to build QATzip
  * Change the API for ABI/API compatibility
  * Change the default installation directory of QATzip lib to
    /usr/local/lib
  * Bug fix
* Fri Jul  1 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Add qatzip-fortify_source=3.patch: Use distro default CFLAGS.
  Resolves a clash between source defined FORTIFY_SOURCE=3 and
  distro defined FORTIFY_SOURCE=3.
* Thu Dec  9 2021 Torsten Duwe <duwe@suse.com>
- fix devel dependency that was missed at the shared library
  policy enforcement.
- submit for jira feature SLE-20906
* Thu Dec  2 2021 Torsten Duwe <duwe@suse.com>
- apply shared library naming policy
- submit for jira feature SLE-20906
* Thu Nov 25 2021 Torsten Duwe <duwe@suse.com>
- copy from home:zm627 and polish
